@@ -83,8 +83,7 @@ install() {
 
 		for _service in \
 			"zfs-import-scan.service" \
-			"zfs-import-cache.service" \
-			"zfs-load-module.service"; do
+			"zfs-import-cache.service"; do
 			inst_simple "${systemdsystemunitdir}/${_service}"
 			systemctl -q --root "${initdir}" add-wants zfs-import.target "${_service}"
 		done
